@@ -27,6 +27,15 @@ use autodie;
 use constant NUMPY_STRING => 'module compiled against ABI version %x'
   . ' but this version of numpy is %x';
 
+# These are the ones file(1) looks for.  The ".zdebug_info" being the
+# compressed version of .debug_info.
+# - Technically, file(1) also looks for .symtab, but that is apparently
+#   not strippable for static libs.  Accordingly, it is omitted below.
+use constant DEBUG_SECTIONS => qw(.debug_info .zdebug_info);
+
+use File::Spec;
+use List::MoreUtils qw(any);
+
 use Lintian::Check qw(check_spelling spelling_tag_emitter);
 use Lintian::Data;
 use Lintian::Relation qw(:constants);
@@ -34,8 +43,6 @@ use Lintian::Tags qw(tag);
 use Lintian::Output qw(debug_msg);
 use Lintian::Util qw(fail slurp_entire_file strip);
 
-use File::Spec;
-
 my $ARCH_REGEX = Lintian::Data->new('binaries/arch-regex', qr/\s*\~\~/o,
     sub { return qr/$_[1]/ });
 my $ARCH_64BIT_EQUIVS
@@ -145,9 +152,10 @@ sub run {
             my ($foo, $sec, $sym) = @{$symbol};
 
             unless (defined $has_lfs) {
-                if ($LFS_SYMBOLS->known($sym)) {
+                if ($foo eq 'UND' and $LFS_SYMBOLS->known($sym)) {
                     # Using a 32bit only interface call, some parts of the
-                    # binary are built without LFS.
+                    # binary are built without LFS. If the symbol is defined
+                    # within the binary then we ignore it
                     $has_lfs = 0;
                 }
             }
@@ -191,10 +199,10 @@ sub run {
         # not know the multi-arch path for a known architecture) , we assume
         # it the multi-arch path to be this (hopefully!) non-existent path to
         # avoid warnings about uninitialized variables.
-        $madir = './!non-existant-path!/./';
+        $madir = './!non-existent-path!/./';
     }
 
-    $madir = './!non-existant-path!/./' unless defined $madir;
+    $madir = './!non-existent-path!/./' unless defined $madir;
 
     $gnu_triplet_re = quotemeta $madir;
     $gnu_triplet_re =~ s,^i386,i[3-6]86,;
@@ -288,7 +296,7 @@ sub run {
 
         if ($multiarch eq 'same') {
             unless ($fname
-                =~ m,\b$gnu_triplet_re\b|/(?:$ruby_triplet_re|java-\d+-openjdk-\Q$arch\E|\.build-id)/,
+                =~ m,\b$gnu_triplet_re(?:\b|_)|/(?:$ruby_triplet_re|java-\d+-openjdk-\Q$arch\E|\.build-id)/,
               ) {
                 tag 'arch-dependent-file-not-in-arch-specific-directory',$file;
             }
@@ -306,8 +314,14 @@ sub run {
                 # Shouldn't happen, but...
                 fail("object ($file $obj) in static lib is missing!?")
                   unless defined $libobj;
-                tag_unneeded_sections('static-library-has-unneeded-section',
-                    "${file}(${obj})", $libobj);
+
+                if (any { exists($libobj->{'SH'}{$_}) } DEBUG_SECTIONS) {
+                    tag 'unstripped-static-library', "${file}(${obj})";
+                } else {
+                    tag_unneeded_sections(
+                        'static-library-has-unneeded-section',
+                        "${file}(${obj})", $libobj);
+                }
             }
         }
 
@@ -350,6 +364,7 @@ sub run {
             'teH' => 1, # From #711207
             'tEH' => 1, # From #782902
             'tEh' => 1, # From #782902, too
+            'ang' => 1, # The Go stdlib html/ package contains "ang;"
         };
         my $tag_emitter
           = spelling_tag_emitter('spelling-error-in-binary', $file);
@@ -464,13 +479,21 @@ sub run {
         # statically linked?
         if (!scalar(@{ $objdump->{NEEDED} })) {
             if ($fileinfo =~ m/shared object/o) {
-                # Some exceptions: kernel modules, detached debugging
-                # information and the dynamic loader (which itself has
-                # no dependencies).
+                # Some exceptions: kernel modules, syslinux modules, detached
+                # debugging information and the dynamic loader (which itself
+                # has no dependencies).
+                next if ($fname =~ m%^boot/modules/%);
                 next if ($fname =~ m%^lib/modules/%);
                 next if ($fname =~ m%^usr/lib/debug/%);
+                next if ($fname =~ m%\.(?:[ce]32|e64)$%);
                 next
-                  if ($fname =~ m%^lib(?:|32|64)/(?:[\w/]+/)?ld-[\d.]+\.so$%);
+                  if (
+                    $fname =~ m{
+                                  ^lib(?:|32|x32|64)/
+                                   (?:[-\w/]+/)?
+                                   ld-[\d.]+\.so$
+                                }xsm
+                  );
                 tag 'shared-lib-without-dependency-information', $file;
             } else {
                 # Some exceptions: files in /boot, /usr/lib/debug/*,
@@ -532,6 +555,12 @@ sub run {
                 if ($flags) {
                     foreach my $t (@{$info->hardening_info->{$fname}}) {
                         my $tag = "hardening-$t";
+                        # Binaries built by the Go compiler do not support all
+                        # hardening measures.
+                        next
+                          if ($t eq 'no-relro'
+                            ||$t eq 'no-fortify-functions')
+                          &&$built_with_golang;
                         tag $tag, $file if $flags->{$tag};
                     }
                 }
