@@ -330,7 +330,7 @@ sub run {
                     tag 'possible-new-upstream-release-without-new-version';
                 }
                 if ($first_debian =~ /^\d+$/ and $second_debian =~ /^\d+$/) {
-                    unless ($second_debian == $first_debian + 1) {
+                    unless ($first_debian == $second_debian + 1) {
                         tag 'non-consecutive-debian-revision';
                     }
                 }
@@ -383,6 +383,10 @@ sub run {
             }
         }
 
+        if($changes =~ /Close:\s+(\#\d+)/xi) {
+            tag 'misspelled-closes-bug',$1;
+        }
+
         my $changesempty = $changes;
         $changesempty =~ s,\W,,gms;
         if (length($changesempty)==0) {
