@@ -359,14 +359,14 @@ sub run {
         my $build_all = $info->relation('build-depends-all');
         my $build_conflicts_all = $info->relation('build-conflicts-all');
         tag 'restriction-formula-without-versioned-dpkg-dev-dependency'
-          unless ($build_all->implies('dpkg-dev (>= 1.17.14)'));
+          unless ($build_all->implies('dpkg-dev (>= 1.17.14~)'));
         tag 'restriction-formula-with-versioned-dpkg-dev-conflict'
           if ($build_conflicts_all->implies_inverse('dpkg-dev (<< 1.17.14)'));
         # if the package uses debhelper then it must require and not
         # conflict with version >= 9.20141010
         if ($build_all->implies('debhelper')) {
             tag 'restriction-formula-with-debhelper-without-debhelper-version'
-              unless ($build_all->implies('debhelper (>= 9.20141010)'));
+              unless ($build_all->implies('debhelper (>= 9.20141010~)'));
             #<<< no tidy, tag name too long
             tag 'restriction-formula-with-debhelper-with-conflicting-version'
             #>>>
@@ -379,13 +379,11 @@ sub run {
     # find binary packages that Pre-Depend on multiarch-support without going
     # via ${misc:Pre-Depends}
     if ($info->source_field('build-depends')) {
-        if ($info->source_field('build-depends') =~ /debhelper/) {
-            for my $bin (@package_names) {
-                my $raw = $info->binary_field($bin, 'pre-depends');
-                next unless $raw;
-                if($raw =~ /multiarch-support/) {
-                    tag 'pre-depends-directly-on-multiarch-support',$bin;
-                }
+        for my $bin (@package_names) {
+            my $raw = $info->binary_field($bin, 'pre-depends');
+            next unless $raw;
+            if($raw =~ /multiarch-support/) {
+                tag 'pre-depends-directly-on-multiarch-support',$bin;
             }
         }
     }
