@@ -661,6 +661,25 @@ sub find_cruft {
             tag 'debian-upstream-obsolete-path', $name;
         }
 
+        # Find mentioning of usr/lib/perl5 inside the packaging
+        if ($name =~ m{^debian/}) {
+            my $short = $entry->basename();
+
+            # Skip symlinks and other nasty stuff as well as
+            # debian/changelog
+            if (   $short ne 'changelog'
+                && $entry->is_file
+                && $entry->is_open_ok) {
+                my $contents = $entry->file_contents;
+
+                # ignore comments
+                $contents =~ s/#.*$//m;
+                if (index($contents, 'usr/lib/perl5') >= 0) {
+                    tag 'mentions-deprecated-usr-lib-perl5-directory', $short;
+                }
+            }
+        }
+
         if (   $basename eq 'doxygen.png'
             or $basename eq 'doxygen.sty') {
             unless ($source_pkg eq 'doxygen') {
@@ -775,7 +794,12 @@ sub check_missing_source {
             }
             # relative path
             else {
-                $newpath = normalize_pkg_path($dirname.'/'.$newbasename);
+                $newpath
+                  = normalize_pkg_path($dirname.'/'.$path.'/'.$newbasename);
+            }
+            # path outside package
+            if(!defined($newpath)) {
+                next PATH;
             }
             # ok we get same name => next
             if($newpath eq $name) {
@@ -912,31 +936,63 @@ sub _search_in_block0 {
     return;
 }
 
-# try to detect non human source based on line length
-sub _linelength_test {
-    my ($entry, $info, $name, $basename, $dirname, $block) = @_;
-    my $strip = $block;
-    # from perl faq strip comments
-    $strip
-      =~ s#/\*[^*]*\*+([^/*][^*]*\*+)*/|//([^\\]|[^\n][\n]?)*?(?=\n)|("(\\.|[^"\\])*"|'(\\.|[^'\\])*'|.[^/"'\\]*)#defined $3 ? $3 : ""#gse;
-    # strip empty line
-    $strip =~ s/^\s*\n//mg;
-    # remove last \n
-    $strip =~ s/\n\Z//m;
-    # compute now means line length
-    my $total = length($strip);
-    if($total > 0) {
-        my $linelength = $total/($strip =~ tr/\n// + 1);
-        if($linelength > 255) {
+# detect if max line of block is > cutoff
+# return false if file is minified
+sub _linelength_test_maxlength_ok {
+    my ($entry, $info, $name, $basename, $dirname, $block, $cutoff) = @_;
+    while($block =~ /([^\n]+)\n?/g){
+        my $linelength = length($1);
+        if($linelength > $cutoff) {
             tag 'source-contains-prebuilt-javascript-object',
-              $name, 'mean line length is about', int($linelength),
-              'characters';
+              $name, 'line length is', int($linelength),
+              "characters (>$cutoff)";
             # Check for missing source.  It will check
             # for the source file in well known directories
             check_missing_source($entry,$info,$name,$basename,$dirname,
                 [['(?i)\.js$','.debug.js'],['(?i)\.js$','-debug.js'],['','']]);
+            return 0;
         }
     }
+    return 1;
+}
+
+# try to detect non human source based on line length
+sub _linelength_test {
+    my ($entry, $info, $name, $basename, $dirname, $block) = @_;
+
+    # first check if line > 1024 that is likely minification
+    if(
+        _linelength_test_maxlength_ok(
+            $entry, $info, $name, $basename, $dirname, $block,1024
+        )
+      ) {
+# now try to be more clever and work only on the 8192 character in order to avoid
+# regexp recursion problems
+        my $strip = substr($block,0,8192);
+        # strip indention
+        $strip =~ s/^\s+//g;
+        # from perl faq strip comments
+        $strip =~ s{
+                     # Strip /* */ comments
+                     /\* [^*]*+ \*++ (?: [^/*][^*]*+\*++ ) */
+                     # Strip // comments (C++ style)
+                  |  // (?: [^\\] | [^\n][\n]? )*? (?=\n)
+                  |  (
+                         # Keep "/* */" (etc) as is
+                         "(?: \\. | [^"\\]++)*"
+                         # Keep '/**/' (etc) as is
+                       | '(?: \\. | [^'\\]++)*'
+                         # Keep anything else
+                       | .[^/"'\\]*+
+                     )
+                   }{defined $1 ? $1 : ""}xgse;
+        # strip empty line
+        $strip =~ s/^\s*\n//mg;
+        # remove last \n
+        $strip =~ s/\n\Z//m;
+        _linelength_test_maxlength_ok($entry, $info, $name, $basename,
+            $dirname, $strip,256);
+    }
     return;
 }
 
@@ -961,9 +1017,16 @@ sub _check_gfdl_license_problem {
     my $gfdlsections  = _strip_punct($rawgfdlsections);
     my $contextbefore = _strip_punct($rawcontextbefore);
 
-    my $oldgfdlsections;
+    # remove line number at beginning of line
+    # see krusader/1:2.4.0~beta3-2/doc/en_US/advanced-functions.docbook/
+    $gfdlsections =~ s{[ ]\d+[ ]}{ }gxsmo;
+    $gfdlsections =~ s{^\d+[ ]}{ }xsmo;
+    $gfdlsections =~ s{[ ]\d+$}{ }xsmo;
+    $gfdlsections =~ s{[ ]+}{ }xsmo;
+
     # remove classical and without meaning part of
     # matched string
+    my $oldgfdlsections;
     do {
         $oldgfdlsections = $gfdlsections;
         $gfdlsections =~ s{ \A \(?[ ]? g?fdl [ ]?\)?[ ]? [,\.;]?[ ]?}{}xsmo;
@@ -983,6 +1046,7 @@ sub _check_gfdl_license_problem {
                        permission [ ] is [ ] granted [ ] to [ ] copy [ ]?[,\.;]?[ ]?
                        distribute [ ]?[,\.;]?[ ]? and[ ]?/?[ ]?or [ ] modify [ ]
                        this [ ] document [ ] under [ ] the [ ] terms [ ] of [ ] the\Z}{}xsmo;
+
     # Treat ambiguous empty text
     unless(
         defined(
