@@ -55,7 +55,9 @@ my $KNOWN_PRIOS = Lintian::Data->new('common/priorities', qr/\s*=\s*/o);
 our @supported_source_formats = (qr/1\.0/, qr/3\.0\s*\((quilt|native)\)/);
 
 # Still in the archive but shouldn't be the primary Emacs dependency.
-our %known_obsolete_emacs = map { $_ => 1 } ('emacs21', 'emacs22');
+our %known_obsolete_emacs = map { $_ => 1 }
+  map { $_, $_.'-el', $_.'-gtk', $_.'-nox', $_.'-lucid' }
+  qw(emacs21 emacs22 emacs23);
 
 our %known_libstdcs = map { $_ => 1 } (
     'libstdc++2.9-glibc2.1', 'libstdc++2.10',
@@ -94,7 +96,7 @@ our @known_java_pkg = map { qr/$_/ } (
 # Mapping of package names to section names
 my @NAME_SECTION_MAPPINGS = (
     [qr/-docs?$/                      => 'doc'],
-    [qr/-dbg$/                        => 'debug'],
+    [qr/-dbg(?:sym)?$/                => 'debug'],
     [qr/^(?:python-)?zope/            => 'zope'],
     [qr/^python-/                     => 'python'],
     [qr/^r-cran-/                     => 'gnu-r'],
@@ -781,7 +783,7 @@ sub run {
 
                     tag 'package-depends-on-an-x-font-package',
                       "$field: $part_d_orig"
-                      if ( $field =~ /^(pre-)?depends$/
+                      if ( $field =~ /^(?:pre-)?depends$/
                         && $d_pkg =~ /^xfont.*/
                         && $d_pkg ne 'xfonts-utils'
                         && $d_pkg ne 'xfonts-encodings');
@@ -819,7 +821,7 @@ sub run {
                       if ("$d_pkg-doc" eq $pkg
                         && $field =~ /^(?:pre-)?depends$/);
 
-                    # only trigger this for the the preferred alternative
+                    # only trigger this for the preferred alternative
                     tag 'versioned-dependency-satisfied-by-perl',
                       "$field: $part_d_orig"
                       if $alternatives[0][-1] eq $part_d_orig
@@ -827,6 +829,13 @@ sub run {
                       && perl_core_has_version($d_pkg, $d_version->[0],
                         $d_version->[1]);
 
+                    tag 'package-relation-with-perl-modules', "$field: $d_pkg"
+                      # matches "perl-modules" (<= 5.20) as well as
+                      # perl-modules-5.xx (>> 5.20)
+                      if $d_pkg =~ /^perl-modules/
+                      && $field ne 'replaces'
+                      && $proc->pkg_src ne 'perl';
+
                     tag 'depends-exclusively-on-makedev', $field,
                       if ( $field eq 'depends'
                         && $d_pkg eq 'makedev'
@@ -1059,7 +1068,14 @@ sub run {
                           if ($d_version->[0]
                             && !version_check($d_version->[1]));
 
-                        # only trigger this for the the preferred alternative
+                        tag 'package-relation-with-perl-modules',
+                          "$field: $part_d_orig"
+                          # matches "perl-modules" (<= 5.20) as well as
+                          # perl-modules-5.xx (>> 5.20)
+                          if $d_pkg =~ /^perl-modules/
+                          && $proc->pkg_src ne 'perl';
+
+                        # only trigger this for the preferred alternative
                         tag 'versioned-dependency-satisfied-by-perl',
                           "$field: $part_d_orig"
                           if $alternatives[0][-1] eq $part_d_orig
@@ -1163,6 +1179,23 @@ sub run {
         if ($arch_dep_packages == 0 and $build_all->implies($PYTHON_DEV)) {
             tag 'build-depends-on-python-dev-with-no-arch-any';
         }
+
+        # libmodule-build-perl
+        # matches() instead of implies() because of possible OR relation
+        if ($info->relation('build-depends-indep')
+            ->matches(qr/^libmodule-build-perl$/, VISIT_PRED_NAME)
+            && !$info->relation('build-depends')
+            ->matches(qr/^libmodule-build-perl$/, VISIT_PRED_NAME)) {
+            tag 'libmodule-build-perl-needs-to-be-in-build-depends';
+        }
+
+        # libmodule-build-tiny-perl
+        if ($info->relation('build-depends-indep')
+            ->implies('libmodule-build-tiny-perl')
+            && !$info->relation('build-depends')
+            ->implies('libmodule-build-tiny-perl')) {
+            tag 'libmodule-build-tiny-perl-needs-to-be-in-build-depends';
+        }
     }
 
     #----- Origin
