@@ -423,7 +423,7 @@ sub run {
                 my $oldpath  = $obs_data->{'olddir'};
                 my $newpath  = $obs_data->{'newdir'};
                 my $moreinfo = $obs_data->{'moreinfo'};
-                tag 'package-install-into-obsolete-dir',
+                tag 'package-installs-into-obsolete-dir',
                   "$file : $oldpath -> $newpath (see also $moreinfo)";
             }
         }
@@ -435,26 +435,36 @@ sub run {
                     =~ m,/(?:[^/]-)?(?:oui|iab)(?:\.(txt|idx|db))?(?:\.$COMPRESS_FILE_EXTENSIONS_OR_ALL)?\Z,x
                   ) {
                     unless ($source_pkg eq 'ieee-data') {
-                        tag 'package-install-ieee-data', $file;
+                        tag 'package-installs-ieee-data', $file;
                     }
                 }
             }
         }
 
+        # build directory
+        if (   $fname =~ m,^var/cache/pbuilder/build/,
+            or $fname =~ m,^var/lib/sbuild/,
+            or $fname =~ m,^var/lib/buildd/,
+            or $fname =~ m,^build/,
+            or $fname =~ m,^tmp/buildd/,) {
+            unless ($source_pkg eq 'sbuild') {
+                tag 'dir-or-file-in-build-tree', $file;
+            }
+        }
         # ---------------- /etc
-        if ($fname =~ m,^etc/,) {
+        elsif ($fname =~ m,^etc/,) {
             # /etc/apt
             if ($fname =~ m,^etc/apt/,) {
                 # -----------------/etc/apt/preferences
                 if ($fname =~ m,^etc/apt/preferences(?:$|\.d/),) {
                     unless ($source_pkg eq 'apt') {
-                        tag 'package-install-apt-preferences', $file;
+                        tag 'package-installs-apt-preferences', $file;
                     }
                 }
                 # -----------------/etc/apt/sources
                 if ($fname =~ m,^etc/apt/sources\.list(?:$|\.d/),) {
                     unless ($source_pkg eq 'apt') {
-                        tag 'package-install-apt-sources', $file;
+                        tag 'package-installs-apt-sources', $file;
                     }
                 }
             }
@@ -952,14 +962,6 @@ sub run {
         elsif ($fname =~ m,^srv/.,) {
             tag 'dir-or-file-in-srv', $file;
         }
-        # build directory
-        elsif ($fname =~ m,^var/cache/pbuilder/build/.,
-            or $fname =~ m,^var/lib/sbuild/.,
-            or $fname =~ m,^var/lib/buildd/.,) {
-            unless ($source_pkg eq 'sbuild') {
-                tag 'dir-or-file-in-build-tree', $file;
-            }
-        }
         # ---------------- FHS directory?
         elsif (
                 $fname =~ m,^[^/]+/$,o
@@ -1014,7 +1016,7 @@ sub run {
                 or $fname =~ m,^usr/iraf/,
                 # not allowed, but tested indivudually
                 or $fname =~ m{\A (?:
-                        home|mnt|opt|root|run|srv
+                        build|home|mnt|opt|root|run|srv
                        |(?:(?:usr|var)/)?tmp)|var/www/}xsm
               ) {
                 tag 'file-in-unusual-dir', $file;
@@ -1931,7 +1933,8 @@ sub _check_tag_url_privacy_breach {
     }
     # reparse fulltag for rel
     if ($tagattr eq 'link') {
-        $fulltag =~ m,<link
+        my $rel = $fulltag;
+        $rel =~ m,<link
                       (?:\s[^>]+)? \s+
                       rel="([^"\r\n]*)"
                       [^>]*
@@ -1947,6 +1950,19 @@ sub _check_tag_url_privacy_breach {
             } elsif ($relcontent eq 'generator-home') {
                 # generator-home is used by texinfo
                 return;
+                # reparse for alternate (css alternate is loaded)
+            } elsif ($relcontent eq 'alternate') {
+                my $type = $fulltag;
+                $type =~ m,<link
+                      (?:\s[^>]+)? \s+
+                      type="([^"\r\n]*)"
+                      [^>]*
+                      >,xismog;
+                my $typecontent = $1;
+                if($typecontent eq 'application/rdf+xml') {
+                    # see #79991
+                    return;
+                }
             }
         }
     }
